@@ -764,7 +764,7 @@ gsd_xrandr_manager_2_rotate (GsdXrandrManager *manager,
                              guint32           timestamp,
                              GError          **error)
 {
-        handle_rotate_windows (manager, -1, timestamp);
+        handle_rotate_windows (manager, GNOME_RR_ROTATION_NEXT, timestamp);
         return TRUE;
 }
 
@@ -1301,8 +1301,8 @@ generate_fn_f7_configs (GsdXrandrManager *mgr)
         g_ptr_array_add (array, gnome_rr_config_new_current (screen, NULL));
         g_ptr_array_add (array, make_clone_setup (mgr, screen));
         g_ptr_array_add (array, make_xinerama_setup (mgr, screen));
-        g_ptr_array_add (array, make_laptop_setup (mgr, screen));
         g_ptr_array_add (array, make_other_setup (screen));
+        g_ptr_array_add (array, make_laptop_setup (mgr, screen));
 
         array = sanitize (mgr, array);
 
